@@ -6,6 +6,8 @@ if (! $this->CheckPermission('Use MetaMax')) {
 }
 
 $this->SetPreference('analyticstype_title', $params['analyticstype_title']);
+$this->SetPreference('analytics_support',
+		     (isset($params['analytics_support'])?'1':'0'));
 $this->SetPreference('propertyid_title', $params['propertyid_title']);
 $this->SetPreference('webmasterid_title', $params['webmasterid_title']);
 $this->SetPreference('pretty_title',
