@@ -51,6 +51,7 @@ $lang['canonical_block_title_help'] = 'This should be the name given to your can
 $lang['length_title'] = 'Number of words to appear in auto description';
 $lang['auto_title'] = 'Automatically generate a page description where none is provided';
 $lang['base_title'] = 'Generate Base Tag';
+$lang['baseslash_title'] = 'Add trailing slash to base URL?';
 $lang['opendoctype_title'] = 'Generate Doctype tag';
 $lang['doctype_title'] = 'Specify Doctype';
 $lang['doctype_select'] = 'Please select one';
@@ -73,7 +74,7 @@ $lang['html_title'] = 'Specify HTML language (Possible use of smarty variable i.
 $lang['htmlextra_title'] = 'Extra HTML tag content';
 $lang['htmlextra_title_help'] = 'Manifest information for example';
 $lang['openhtml_title'] = 'Generate Opening HTML Tag';
-$lang['xmlns_title'] = 'Inlcude XMLNS';
+$lang['xmlns_title'] = 'Include XMLNS';
 $lang['dir_title'] = 'Include text direction';
 $lang['dirchoice_title'] = 'Text direction';
 $lang['dirchoice_select'] = 'Please select one';
@@ -105,7 +106,7 @@ $lang['standard_title'] = 'Generate standard Meta Tags';
 $lang['jquery_title'] = 'Include &#123;cms_jquery} tag';
 $lang['jquery_exclude'] = 'Exclude parameter';
 $lang['jquery_include'] = 'Include parameter';
-$lang['jquery_cnd'] = 'CND parameter';
+$lang['jquery_cnd'] = 'CDN parameter';
 $lang['jquery_ssl'] = 'SSL parameter';
 $lang['jquery_custom_root'] = 'Custom root parameter';
 $lang['jquery_assign'] = 'Assign parameter';
@@ -250,7 +251,9 @@ $lang['changelog'] = '<ul>
 <li>Version 1.9.7 18 April 2013. Content block variables now appear in order in the description tag, appended by the content of the default Content block by default.</li>
 <li>Version 1.9.8 22 April 2013. Added support for Google Universal Analytics.</li>
 <li>Version 1.9.9 30 April 2013. Added the ability to disable/enable keywords tag.</li>
-<li>Version 1.9.9.1 2 May 2013. Minor bug fixes.</li></ul>';
+<li>Version 1.9.9.1 2 May 2013. Minor bug fixes.</li>
+<li>Version 1.9.9.2 25 June 2013. Stripped files appended with thumb_ from image dropdowns. Added process_pagedata tag to MetaMax output, making the Meta Data field redundant.</li>
+<li>Version 1.9.9.3 30 July 2013. Added trailing slash option for base tag, plus minor language updates spotted by Velden.</li></ul>';
 $lang['help'] = '<h3>What Does This Do?</h3>
 <p>This module adds the ability to include additional Meta data, Analytics tracking code and other useful SEO information. It can also be used to generate Doctype and Head tags, replacing the entire head of your document.</p>
 <h3>How Do I Use It</h3>
